bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 36. Aventiure
___________________________________________________
| ### <Nv> bintet ab di helme sprach Hagen der degen ### ich vnde mine gesellen wir svln iwer pflegen ### vnde wellent iz noch versvchen zv zvns di Eceln man ### so warne ich mine herren so ich aller schiereste chan ### Do entwafent daz hovbet vil manich [397] ritter gvt ### si sazen vf di wnden di vor in in daz plvoist ### waren zv dem tode von ir handen chomen ### da wart der edeln geste vil vebele govm genomen
###### 2080 | ### Noch vor dem abende do shvf der kvnech daz ### vnde ovch div chvneginne daz ez versvchten baz ### di hivnisschen recken der sah man vor in stan ### noch wol zweinzech tvsent si mvsen da ce strite gan
| ### Sich hvb ein stvrm herte zv den gesten san ### Danchwart Hagen <brvder> vil snelle man ### Spranch von sinen herren cen vienden fver di tver ### man wande er wære erstorben er chom gesvnder wol darfver
###### 2082 | ### Der herte strit der werte vnz iz div naht benam ### do werten sich di geste als gvten helden zam ### den Eceln mannen den svmerlangen tach ### hey waz noch chvener degene vor in veige gelach
###### 2083 | ### Ceinen svnewenden daz groze mort geschach ### daz div vrowe Criemhilt ir herceleit errach ### an ir næhesten magen vnde anderem manigem man ### da von der kvenech Ecel vrevde nimmer mer gewan
| ### In was des tages cervnnen do gie in sorgen not ### si gedahten daz in bezer wære ein chvercer tot ### denne lange da ce qvelne vf vngefvegiv leit ### eines vrides si do gerten di stolcen ritter gemeit
###### 2085 | ### Si baten daz man brehte den kvenech zv in dar ### di blvtvarwen helde vnde ovch harnaschvar ### traten vz dem hvse di drie kvenege her ### sine wessen wem ce chlagene div ir vil grozlichen ser
###### 2086 | ### Ecel vnde di chomen beide dar ### daz lant daz was ir eigen des merte sich ir schar ### er sprach zv den gesten nv saget waz welt ir min ### ir wænet vride gewinnen daz chvnde [397b] mvelich gesin
| ### Vf schaden also grozen als ir mir habt getan ### ir svlt is niht geniezen vnde sol ich min leben han ### daz chint daz ir mir slvget vnd vil der mage min ### vrid vnde svne sol iv vil gar versaget sin
###### 2088 | ### Des antwrte Gventher des twanch vns groziv not ### allez min gesinde lach vor dinen helden tot ### an der herberge wi het ich daz versolt ### ich chom zv dir vf triwe ich wande daz mir wærest holt
###### 2089 | ### Do sprach von Bvrgonden Giselher daz chint ### ir Eceln helde di noch hi lebende sint ### waz wizet ir mir recken waz han ich iv getan ### wand ich vrivntliche in diz lant geritten han
| ### Si sprachen diner gvete ist al div bvrch vol ### mit iamer zv dem lande ia gonden wir dir wol ### daz dv ni chomen wærest von Wormez veber Rin ### daz lant habt ir verweiset dv vnt di brvder din
###### 2091 | ### Do sprach in zornes mvte Gventher der degen ### welt ir diz starche hazen ce einer svne legen ### mit vns ellenden recken deist beidenthalben gvt ### ez ist gar ane schvlde swaz vns Ecel getvt
###### 2092 | ### Do sprach der wirt cen gesten min vnd iwer leit ### div sint vil vngeliche div michel arbeit ### des schaden zv den schanden di ich hie <han> genomen ### des sol iwer deheiner nimmer lebende hinnen chomen
| ### Do sprach zv dem chvenege der starche Gernot ### so sol iv got gebieten daz ir frvemelichen tvt ### slaht vns ellenden vnd lat vns zv ziv gan ### hin nider an di wite daz ist iv ere getan
###### 2094 | ### Swaz vns geschehen chvenne daz lat chverzliche ergan ### ir habt so vil gesvnder vnt tvrrens vns bestan ### daz si [398a] stverm mvede lazent niht genesen ### wi lange svln wir recken in disen arbeiten wesen
###### 2095 | ### Di Eceln recken di hetenz nach getan ### daz si si wolden lazen fver den palas gan ### daz gehorte Criemhilt ez was ir harte leit ### des wart den ellenden der vride ce gahes verseit
| ### Neina Hivnen recken des ir da habt mvt ### ich rat an rehten triwen daz ir des niht entvt ### daz ir di mortræzen lazet fver den sal ### so mvsen iwer mage liden den totlichen val
###### 2097 | ### Ob ir nv niemen lebte wan div Vten chint ### min edele brvder vnde choment si an den wint ### erchvlent in di ringe so sit ir alle vlorn ### ezen wrden chvener degene ni cer werld geborn
###### 2098 | ### Do sprach der ivnge Giselher vil schoniv swester min ### des trvte ich vil vebele daz dv mich veber Rin ### ladetes her ce lande in dise groze not ### wi han ich an den Hivnen hi verdienet den tot
| ### Ich was dir ie getriwe ni getet ich dir leit ### vf solhen gedingen ich her ce lande reit ### daz dv mir holt wærest vil liebiv swester min ### bedenche an vns genade ez mach niht anders nv gesin
###### 2100 | ### Ine mach iv niht genaden vngenade ich han ### mir hat von Tronege Hagene so groziv leit getan ### ez ist vil vnvesvenet di wil ich han den lip ### ir mvezetes alle engelten sprach daz Eceln wip
###### 2101 | ### Welt <ir> mir Hagenen einen her ce gisel geben ### sone wil ich nith versprechen ich <welli> ivch lazen leben ### wande ir sit mine brvder vnde einer mvter chint ### so red ichez nach der svone mit disen helden di hie sint
| ### Nvne welle got von himele sprach do Gernot ### ob vnser tvsent wæren wir lægen alle tot ### der sippen diner mage ê wir dir einen man ### gæben [398b] hi ce gisel ez wirdet nimmer getan
###### 2103 | ### Wir mvesen doch ersterben sprach do Giselher ### vns scheidet niemen von ritterlicher wer ### swer gerne mit vns vehte wir sin et aber hie ### wande ich deheinen minen frivnt an den triwen ni verlie
###### 2104 | ### Do sprach der chvne Danchwart im zæme niht ce dagene ### iane stet niht eine min brvoder Hagene ### di hi den vride versprechent ez mach in werden leit ### des bringe ich ivch wol innen daz si iv wærliche geseit
| ### Do sprach div chvneginne ir helde vil gemeit ### nv get der stiege naher vnde rechet miniv leit ### daz wil ich immer dienen als ich von rehte sol ### der Hagenen vebermvete der gelon ich im wol
###### 2106 | ### Lat einen vz dem hvse niht chomen veber al ### si hiez viern enden zvenden an den sal ### so werdent wol errochen elliv miniv leit ### di Eceln degene wrden schiere bereit
###### 2107 | ### Di nahe hi vze stvnden di tribens in den sal ### mit slegen vnde mit shvezen des wart vil groz der schal ### doh wolden nie gescheiden di fversten vnd ir man ### sine chonden vor ir triwen ein ander niht verlan
| ### Den sal den hiez do zvenden daz Eceln wip ### do quelte man den recken mit fiwer da den lip ### daz hvs von einem winde vil balde allez bran ### ich wæne daz <volch> einheinez grozzer angest nie gewan
###### 2109 | ### Genvge rvfften drinne owe dirre not ### wir mohten michel gerner sin in stvrme tot ### ez mohte got erbarmen wi sin wir alle vlorn ### nv richet vngevvege an vns div kveneginne ir zorn
###### 2110 | ### Ir einer sprach dar inne wir mvezen ligen tot ### waz hilffet vns daz grvezzen daz vns der kvenech enbot ### mir tvt von starcher hice der dvrst so rehte we ### des wæn min leben shier in disen sorgen cerge [399a]
| ### Do sprach von Tronege Hagene ir edel ritter gvt ### swen twinge dvrstes not der trinche hie daz plvt ### daz ist in solher hice bezer danne win ### ezen mach an disen ziten et nv niht bezer gesin
###### 2112 | ### Do gie der recken einer da er einen toten vant ### er kniete im zv den wnden den helm er ab gebant ### do begond er trinchen daz vliezende plvt ### swi vngevon ers wære ez dvhte in grozliche gvt
###### 2113 | ### Nv lon iv got her Hagene sprach der mvede man ### daz ich von iwer lere so wol getrvnchen han ### mir ist noch vil selten geshenchet bezer win ### lebe ich deheine wile ich sol iv immer wæge sin
| ### Do di ander daz gehorten daz ez in dvhte gvt ### do wart ir michel mere di trvnchen ovch daz plvt ### da von gewan vil crhepfte ir etesliches lip ### des engalt an lieben frivnden sit vil manech wætlich wip
###### 2115 | ### Daz fiwer viel genote vf si in den sal ### do leiten siz mit schilden von in hince tal ### der rovch vnd ovch div hice in taten beidiv we ### ich wæne den iamer immer mer an helden erge
###### 2116 | ### Do sprach von Tronege Hagene stet zv des sals want ### lat niht di brende vallen vf iwer halmbant ### tret si mit den fvzen nider in daz plvt ### ez ist ein vebel hohzit di vns div chvneginne git
| ### In svs getanen leiden der naht in doch ceran ### noch stvnt vor dem hvse der chvene spileman ### vnde Hagen sin geselle geleinet veber rant ### si warten shaden mere von den vz Eceln lant
###### 2118 | ### Do sprach der videlære nv ge wir in den sal ### so wænent des di Hivnen daz wir sin veber al ### tot von dirre quale div an vns ist getan ### si sehent vns <noh> begene in strite ir etelichen stan
###### 2119 | ### Do sprach von Bvrgonden Giselher [399b] daz chint ### ich wæn ez tagen welle sich hebt ein chvler wint ### nv laz vns got von himele ein lieber zit geleben ### vns hat min swester Criemhilt ein arge hohzit gegeben
| ### Do sprach aber einer ich chivse nv den tach ### sit daz ez vns nv bezer wesen niht en mach ### so wafent ir ivch helde gedenchet an den lip ### ia chvemt vns aber schiere des chvenech Eceln wip
###### 2121 | ### Der wirt der wolde wænen di geste waren tot ### von ir arbeite vnd von des fiwers not ### do lebt ir noch dar inne sehs hvndert chvener man ### daz nie chvenech deheiner bezer degene gewan
###### 2122 | ### Der ellenden hvte het man wol ersehen ### daz noch di geste lebten swi vil in was geschehen ### ce shaden vnt ce leide den herren vnde ir man ### man sach si in dem gademe noch vil wol gesvnde stan
| ### Man sagete Criemhilde ir wære vil genesen ### do sprach div chveneginne daz chvnde nimmer wesen ### daz ir deheiner lebte von des fiwers not ### ich wil des baz getrwen daz si alle ligen tot
###### 2124 | ### Noch genæsen gerne di fversten vnd ir man ### ob noch iemen wolde genade an in began ### dine chvnden si niht vinden an den von Hivnen lant ### da râchen si ir sterben mit vil werlicher hant
###### 2125 | ### Des tages wider morgen grvezen man in bot ### mit hertem vrlivge des chomen helde in not ### do wart zv zin geshozen vil manech herter ger ### sich werten ritterlichen di recken chvene vnde her
| ### Dem Eceln gesinde erwegt was der mvt ### daz si wolden daz Criemhilde gvt ### dar zv si wolden leisten daz in der chvenech gebot ### des mvse maneger schiere von in chiesen den tot
###### 2127 | ### Von geheize vnde von gabe man mohte wnder sagen ### si hiez golt [400a] daz rote dar in mit schilden tragen ### si gab ez swer sin rvchte vnd ez wolde enpfan ### iane wart nie grozer solden mer vf viende getan
| ### Ein michel chrapft der recken dar zv gewaffent gie ### do sprach der chvene Volker wir sint et aber hie ### ine gesach <nie> vf vehten helde gerner chomen ### di daz golt des chveneges vns ce vare hant genomen
###### 2129 | ### <Do> riefen da genvge naher helde baz ### daz wir da svln verdienen vnde <tvn> bezite daz ### hie belibet niemen want der doh sterben sol ### do sach man schier ir schilde stechen gere schveze vol
###### 2130 | ### Waz mach ich sagen mere wol zwelf hvndert man ### di versv^chtenz vil sere wider vnde dan ### do chvlten mit den wnden di geste wol ir mvt ### ez mohte niemen gescheiden des sach man vlizen daz plvt
###### 2131 | ### von verchtiefen wnden der wart da vil geslagen ### ieslichen nach sinen vrivnden horte man sere chlagen ### di biderben stvrben alle dem richen chvnege her ### des heten holde mage nach in grozlichiv ser

<<< Übersicht <<< vorige Seite nächste Seite >>>